Convenience functions
=====================


- `naima.generate_energy_edges`
- `naima.build_data_table`
- `naima.sed_conversion`
- `naima.estimate_B`

API
---

.. module:: naima

.. autofunction:: generate_energy_edges
.. autofunction:: build_data_table
.. autofunction:: sed_conversion
.. autofunction:: estimate_B
